==> ci-hotel_V0.9.11_20101212.zip: ci-hotel_V0.0.11_20101212/system/application/views/admin/roomtypes/form.php <==
<table width="100%">
<tr><td>部屋タイプ名</td><td>
<input type="text" name="roomtype_name" value="<?php echo set_value('roomtype_name', isset($roomtype_name) ? $roomtype_name : ''); ?>" size="80" />
<?php echo form_error('roomtype_name'); ?>
</td></tr>
<tr><td>概要</td><td>
<?php display_ck(array('id' => 'summary'), $summary); ?>
<?php echo form_error('summary'); ?>
</td></tr>
<tr><td>説明</td><td>
<?php display_ck(array('id' => 'description'), $description); ?>
<?php echo form_error('description'); ?>
</td></tr>
<tr><td>期間</td><td>
<input type="text" name="start_date" id="datepicker1" value="<?php echo set_value('start_date', isset($start_date) ? $start_date : ''); ?>" size="30" />
～
<input type="text" name="end_date" id="datepicker2" value="<?php echo set_value('end_date', isset($start_date) ? $end_date : ''); ?>" size="30" />
<?php echo form_error('start_date'); ?>
<?php echo form_error('end_date'); ?>
</td></tr>
<tr><td>一日あたりの数</td><td>
<input type="text" name="default_num" id="s1" value="<?php echo set_value('default_num', isset($default_num) ? $default_num : ''); ?>" size="4" />
<?php echo form_error('default_num'); ?>
</td></tr>
<tr><td>許容人数</td><td>
<table><tr><td>最小:</td><td>
<input type="text" name="guest_min" id="s2" value="<?php echo set_value('guest_min', isset($guest_min) ? $guest_min : ''); ?>" size="4" />
</td><td>～</td>
<td>最大:</td><td>
<input type="text" name="guest_max" id="s3" value="<?php echo set_value('guest_max', isset($guest_max) ? $guest_max : ''); ?>" size="4" />
</td></tr></table>
<?php echo form_error('guest_min'); ?>
<?php echo form_error('guest_max'); ?>
</td></tr>
</table>
<input type="submit" name="submit" value="送信" />

==> ci-hotel_V1.0.0_20101217.zip: ci-hotel_1.0.0_20101217/system/application/views/admin/roomtypes/form.php <==
<table class="inp">
<tr><th>* 部屋タイプ名 :</th><td>
<input type="text" name="roomtype_name" value="<?php echo set_value('roomtype_name', isset($roomtype_name) ? $roomtype_name : ''); ?>" size="80" />
<?php echo form_error('roomtype_name'); ?>
</td></tr>
<tr><th>* 概要 :</th><td>
<?php display_ck(array('id' => 'summary'), $summary); ?>
<?php echo form_error('summary'); ?>
</td></tr>
<tr><th>説明</th><td>
<?php display_ck(array('id' => 'description'), $description); ?>
<?php echo form_error('description'); ?>
</td></tr>
<tr><th>* 期間 :</th><td>
<input type="text" name="start_date" id="datepicker1" value="<?php echo set_value('start_date', isset($start_date) ? $start_date : ''); ?>" size="30" />
～
<input type="text" name="end_date" id="datepicker2" value="<?php echo set_value('end_date', isset($start_date) ? $end_date : ''); ?>" size="30" />
<?php echo form_error('start_date'); ?>
<?php echo form_error('end_date'); ?>
</td></tr>
<tr><th>* 部屋数 :</th><td>
<input type="text" name="default_num" id="s1" value="<?php echo set_value('default_num', isset($default_num) ? $default_num : ''); ?>" size="4" />
<?php echo form_error('default_num'); ?>
</td></tr>
<tr><th>* 受入人数 :</th><td>
<table><tr><td>最小 :</td><td>
<input type="text" name="guest_min" id="s2" value="<?php echo set_value('guest_min', isset($guest_min) ? $guest_min : ''); ?>" size="4" />
</td><td>～</td>
<td>最大 :</td><td>
<input type="text" name="guest_max" id="s3" value="<?php echo set_value('guest_max', isset($guest_max) ? $guest_max : ''); ?>" size="4" />
</td></tr></table>
<?php echo form_error('guest_min'); ?>
<?php echo form_error('guest_max'); ?>
</td></tr>
</table>
<input type="submit" name="submit" value="送信" />
